[−][src]Enum unicode_types::dogra::Dogra
An enum to represent all characters in the Dogra block.
Variants
LetterA\u{11800}: '𑠀'
LetterAa\u{11801}: '𑠁'
LetterI\u{11802}: '𑠂'
LetterIi\u{11803}: '𑠃'
LetterU\u{11804}: '𑠄'
LetterUu\u{11805}: '𑠅'
LetterE\u{11806}: '𑠆'
LetterAi\u{11807}: '𑠇'
LetterO\u{11808}: '𑠈'
LetterAu\u{11809}: '𑠉'
LetterKa\u{1180a}: '𑠊'
LetterKha\u{1180b}: '𑠋'
LetterGa\u{1180c}: '𑠌'
LetterGha\u{1180d}: '𑠍'
LetterNga\u{1180e}: '𑠎'
LetterCa\u{1180f}: '𑠏'
LetterCha\u{11810}: '𑠐'
LetterJa\u{11811}: '𑠑'
LetterJha\u{11812}: '𑠒'
LetterNya\u{11813}: '𑠓'
LetterTta\u{11814}: '𑠔'
LetterTtha\u{11815}: '𑠕'
LetterDda\u{11816}: '𑠖'
LetterDdha\u{11817}: '𑠗'
LetterNna\u{11818}: '𑠘'
LetterTa\u{11819}: '𑠙'
LetterTha\u{1181a}: '𑠚'
LetterDa\u{1181b}: '𑠛'
LetterDha\u{1181c}: '𑠜'
LetterNa\u{1181d}: '𑠝'
LetterPa\u{1181e}: '𑠞'
LetterPha\u{1181f}: '𑠟'
LetterBa\u{11820}: '𑠠'
LetterBha\u{11821}: '𑠡'
LetterMa\u{11822}: '𑠢'
LetterYa\u{11823}: '𑠣'
LetterRa\u{11824}: '𑠤'
LetterLa\u{11825}: '𑠥'
LetterVa\u{11826}: '𑠦'
LetterSha\u{11827}: '𑠧'
LetterSsa\u{11828}: '𑠨'
LetterSa\u{11829}: '𑠩'
LetterHa\u{1182a}: '𑠪'
LetterRra\u{1182b}: '𑠫'
VowelSignAa\u{1182c}: '𑠬'
VowelSignI\u{1182d}: '𑠭'
VowelSignIi\u{1182e}: '𑠮'
VowelSignU\u{1182f}: '𑠯'
VowelSignUu\u{11830}: '𑠰'
VowelSignVocalicR\u{11831}: '𑠱'
VowelSignVocalicRr\u{11832}: '𑠲'
VowelSignE\u{11833}: '𑠳'
VowelSignAi\u{11834}: '𑠴'
VowelSignO\u{11835}: '𑠵'
VowelSignAu\u{11836}: '𑠶'
SignAnusvara\u{11837}: '𑠷'
SignVisarga\u{11838}: '𑠸'
SignVirama\u{11839}: '𑠹'
SignNukta\u{1183a}: '𑠺'
AbbreviationSign\u{1183b}: '𑠻'
Methods
impl Dogra[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case